==> haskell-http-date-0.0.6.1-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.6.1
id: http-date-0.0.6.1-43Eag1IiGcGLlXBS1SicJW
key: http-date-0.0.6.1-43Eag1IiGcGLlXBS1SicJW
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
abi: ad3ec0a7a7f25dc0a5c4bbdb28e58f2c
exposed: True
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
import-dirs: /usr/lib/ghc-8.4.2/site-local/http-date-0.0.6.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/http-date-0.0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/http-date-0.0.6.1
hs-libraries: HShttp-date-0.0.6.1-43Eag1IiGcGLlXBS1SicJW
depends:
    base-4.11.1.0 array-0.5.2.0
    attoparsec-0.13.2.2-AEXZkgs8lo23eqrLiqxiAC bytestring-0.10.8.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             attoparsec-0.13.2.2-AEXZkgs8lo23eqrLiqxiAC=b163fca1a2fb151be52663236861bb33
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.7-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-date
version: 0.0.7
id: http-date-0.0.7-CfMG18pkddlH3WMxWmGdx9
key: http-date-0.0.7-CfMG18pkddlH3WMxWmGdx9
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP Date parser/formatter
description:
    Fast parser and formatter for HTTP Date
category: Network, Web
abi: 58f9ae70b89b76a7bc38d1cbb4123387
exposed: True
exposed-modules:
    Network.HTTP.Date
hidden-modules: Network.HTTP.Date.Converter
                Network.HTTP.Date.Formatter Network.HTTP.Date.Types
                Network.HTTP.Date.Parser
import-dirs: /usr/lib/ghc-8.4.2/site-local/http-date-0.0.7
library-dirs: /usr/lib/ghc-8.4.2/site-local/http-date-0.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/http-date-0.0.7
hs-libraries: HShttp-date-0.0.7-CfMG18pkddlH3WMxWmGdx9
depends:
    base-4.11.1.0 array-0.5.2.0
    attoparsec-0.13.2.2-KnkUxVEson3AzYFappLt2D bytestring-0.10.8.2
    time-1.8.0.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             attoparsec-0.13.2.2-KnkUxVEson3AzYFappLt2D=bb3660ce70d29d644cde35d789165619
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
haddock-interfaces: /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html: /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
